<!-- include contents from the root readme -->

```{include} ../../README.md
---
relative-docs: docs/src/
relative-images:
---
```

```{toctree}
---
caption: 'Contents:'
maxdepth: 3
---
python-api
```
